Optimizers
==========

Off-the-shelf implementations of standard algorithms. Includes classics such
as global-best and local-best. Useful for quick-and-easy optimization
problems.

.. toctree::

   pyswarms.single
   pyswarms.discrete
